#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Merging messages.xml for the firmware update."""


import sys
import os
import locale

import iobase.xmldata as xmldata


ENCODING = "UTF-8"
CATEGORYLIST_PATH = "categorylist"
CATEGORY_NAME = "category"
CATEGORY_KEY_PATH = "code"
CATEGORY_FIND_XPATH_FMT = """category[code="%s"]"""

SUBCATEGORYLIST_PATH = "subcategorylist"
SUBCATEGORY_NAME = "subcategory"
SUBCATEGORY_KEY_PATH = "code"
SUBCATEGORY_FIND_XPATH_FMT = """subcategory[code="%s"]"""

MESSAGEINFOLIST_PATH = "messageinfolist"
MESSAGEINFO_NAME = "messageinfo"
MESSAGEINFO_KEY_PATH = "code"
MESSAGEINFO_FIND_XPATH_FMT = """messageinfo[code="%s"]"""

CODE_NAME = "code"
IGNORE_MESSAGE_CODE_LIST = ["6080000"]


def __merge_list(new_messages_xml, messages_xml, list_xpath,
        item_name, key_in_item_xpath, find_xpath_fmt):
    """Merge a list in "new_mssages_xml" into "messages_xml"."""

    new_list_node = new_messages_xml.get_node(list_xpath)
    list_node = messages_xml.get_node(list_xpath)

    for item_node in new_list_node.get_node_list(item_name):
        key = item_node.get_value(key_in_item_xpath)
        try:
            cur_node = list_node.get_node(find_xpath_fmt % (key,))
            if (cur_node.compare(item_node, ignore_order=True,
                                    ignore_indent=True)):
                cur_node.update(item_node, override=True)
        except:
            list_node.append_child(item_node.get_clone())


def __merge_categorylist(new_messages_xml, messages_xml):
    """Merge "categorylist" tree in "new_mssages_xml" into "messages_xml"."""

    __merge_list(new_messages_xml, messages_xml, CATEGORYLIST_PATH,
        CATEGORY_NAME, CATEGORY_KEY_PATH, CATEGORY_FIND_XPATH_FMT)


def __merge_subcategorylist(new_messages_xml, messages_xml):
    """Merge "subcategorylist" tree in "new_mssages_xml"
       into "messages_xml".
    """

    __merge_list(new_messages_xml, messages_xml, SUBCATEGORYLIST_PATH,
        SUBCATEGORY_NAME, SUBCATEGORY_KEY_PATH, SUBCATEGORY_FIND_XPATH_FMT)


def __merge_messageinfolist(new_messages_xml, messages_xml):
    """Merge "messageinfolist" tree in "new_mssages_xml"
       into "messages_xml".
    """

    __merge_list(new_messages_xml, messages_xml, MESSAGEINFOLIST_PATH,
        MESSAGEINFO_NAME, MESSAGEINFO_KEY_PATH, MESSAGEINFO_FIND_XPATH_FMT)


def __merge_msg(new_messages_xml, messages_xml):
    """Merge "new_mssages_xml" into "messages_xml"."""

    __merge_categorylist(new_messages_xml, messages_xml)
    __merge_subcategorylist(new_messages_xml, messages_xml)
    __merge_messageinfolist(new_messages_xml, messages_xml)


def __delete_ignore_message_node(new_messages_xml):
    """Delete ignore message node in "new_messages_xml"."""

    idx = 0
    messageinfolist = new_messages_xml.get_node(MESSAGEINFOLIST_PATH)
    for messageinfo in messageinfolist.get_node_list(MESSAGEINFO_NAME):
        if messageinfo.get_value(CODE_NAME, "") in IGNORE_MESSAGE_CODE_LIST:
            messageinfolist.delete_child(MESSAGEINFO_NAME, index=idx)
        else:
            idx += 1


#
# Main
#

if len(sys.argv) < 3:
    print "Error: too few arguments!!"
    print
    print "usage : " + sys.argv[0] + " NEW_MESSAGE_XML_PATH MESSAGE_XML_PATH"
    sys.exit(1)

try:
    new_messages_xml = xmldata.XmlConf(sys.argv[1], encoding=ENCODING)
    __delete_ignore_message_node(new_messages_xml)
    messages_xml = xmldata.XmlConf(sys.argv[2], encoding=ENCODING)

    __merge_msg(new_messages_xml, messages_xml)

    tmp_path = sys.argv[2] + "." + str(os.getpid())
    messages_xml.save(tmp_path)
    os.rename(tmp_path, sys.argv[2])

except:
    sys.exit(2)
