# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Test module for information about XML request/response. """


class ReqTypes:
    """Class for defining the XML request types."""

    LOAD                    = "load"
    DETAIL                  = "detail"
    SAVE                    = "save"
    APPLY                   = "apply"
    QUERY                   = "query"
    GET                     = "get"
    ADD                     = "add"
    CREATE                  = "create"
    DELETE                  = "delete"
    REMOVE                  = "remove"
    MODIFY                  = "modify"
    UPDATE                  = "update"
    CLEAR                   = "clear"
    LIST                    = "list"
    AUTH                    = "auth"
    START                   = "start"
    STOP                    = "stop"
    EXECUTE                 = "execute"
    ROTATE                  = "rotate"
    SEND                    = "send"
    RECEIVE                 = "receive"
    NOTIFY                  = "notify"
    CONTROL                 = "control"
    SET                     = "set"
    UNSET                   = "unset"
    ENCODE                  = "encode"
    DECODE                  = "decode"

    INSTALL                 = "install"
    UNINSTALL               = "uninstall"
    CHKERROR                = "chkerror"
    GET_RAIDDEV_INFO        = "get_raiddev_info"
    GET_ELEMENT_INFO        = "get_element_info"
    ACTIVEREPAIR            = "activerepair"
    DELPART                 = "delpart"
    MKPART                  = "mkpart"
    MKFS                    = "mkfs"
    FSCK                    = "fsck"
    MOUNT                   = "mount"
    UNMOUNT                 = "unmount"
    PLAY                    = "play"
    DISPLAY                 = "display"
    SAVELOG                 = "savelog"
    HANDLE_APPLY            = "handle_apply"
    BEEP                    = "beep"
    VALIDATE                = "validate"
    LUMP_REGIST             = "lump_regist"
    NETSHUTDOWN            = "netshutdown"
    BUCKUP                  = "backup"
    SHUTDOWN                = "shutdown"
    REBOOT                  = "reboot"
    SELFCHECK               = "selfcheck"
    CHECK                   = "check"
    SETTLE                  = "settle"
    CHK_EXIST               = "chk_exist"
    CREATE_SWAP             = "create_swap"
    SWAP_CTRL               = "swap_ctrl"
    ENCRYPT                 = "encrypt"
    REBOOT                  = "reboot"
    CHECK_KEYSERVER         = "check_keyserver"
    SET_LOCKKEY             = "set_lockkey"
    SET_KEYSERVER           = "set_keyserver"
    INITIALIZE              = "initialize"
    DOWNLOAD                = "download"
    CSV_TRANSFORM           = "csv_transform"
    ENABLE                  = "enable"
    DISABLE                 = "disable"
    SET_SYSTEMLOG           = "set_systemlog"
    RESTART                 = "restart"
    REGISTER                = "register"
    UNREGISTER              = "unregister"
    EVENT                   = "event"
    SUSPEND                 = "suspend"
    RESUME                  = "resume"
    CHANGE                  = "change"
    DOMAIN_LIST             = "domain_list"
    ADDPART                 = "addpart"
    GETRAIDMODELIST         = "getraidmodelist"
    RESTORE                 = "restore"
    EXTEND                  = "extend"
    SWITCH                  = "switch"
    IMPORT                  = "import"
    EXPORT                  = "export"
    SCAN                    = "scan"


class Results:
    """Class for defining the XML result codes."""

    OK                      = "0"
    INVALID_TYPE            = "1"
    INVALID_XML             = "2"
    INVALID_FILE            = "3"
    INTERNAL_ERROR          = "4"
    PRE_PROCESS_ERROR       = "5"
    POST_PROCESS_ERROR      = "6"
    INVALID_DATA            = "7"

    # About System Error
    FILE_NOT_FOUND          = "256"
    DEVICE_NOT_FOUND        = "257"
    OPEN_ERROR              = "258"

    # Commnad Specific Error
    LOAD_ERROR              = "1024"
    DETAIL_ERROR            = "1025"
    SAVE_ERROR              = "1026"
    QUERY_ERROR             = "1027"
    ADD_ERROR               = "1028"
    MODIFY_ERROR            = "1029"
    APPLY_ERROR             = "1030"
    UPDATE_ERROR            = "1031"
    CREATE_ERROR            = "1032"
    DELETE_ERROR            = "1033"
    CLEAR_ERROR             = "1034"
    LIST_ERROR              = "1035"
    AUTH_ERROR              = "1036"
    GET_ERROR               = "1037"
    START_ERROR             = "1038"
    STOP_ERROR              = "1039"
    EXECUTE_ERROR           = "1040"
    MAKE_ERROR              = "1041"
    MKFS_ERROR              = "1042"
    FSCK_ERROR              = "1043"
    SEND_ERROR              = "1044"
    CHECK_ERROR             = "1045"
    DISPLAY_ERROR           = "1046"
    AUTOBOOT_ERROR          = "1047"
    RTCCONF_ERROR           = "1048"
    SHUTDOWN_ERROR          = "1049"
    REBOOT_ERROR            = "1050"
    DISCONNECTED            = "1051"
    NO_LOCKKEY              = "1053"
    SET_ERROR               = "1054"
    INVALID_SET_TYPE        = "1055"
    MAX_EXCEED_ERROR        = "1057"
    NO_PROXY                = "1058"
    INSTALL_ERROR           = "1059"
    UNINSTALL_ERROR         = "1060"
    DOWNLOAD_ERROR          = "1061"
    INITIALIZE_ERROR        = "1062"
    OLD_VERSION_ERROR       = "1063"
    ALREADY_EXIST           = "1064"
    MOUNT_ERROR             = "1065"
    UNMOUNT_ERROR           = "1066"
    UNSET_ERROR             = "1067"
    CONNECT_ERROR           = "1068"
    RECEIVE_ERROR           = "1069"
    ENCODE_ERROR            = "1070"
    DECODE_ERROR            = "1071"
    HANDLER_ERROR           = "1072"
    SUSPEND_ERROR           = "1073"
    RESUME_ERROR            = "1074"
    CHANGE_ERROR            = "1075"
    EVENT_ERROR             = "1076"
    CAP_SHORTAGE            = "1077"
    LUMP_REGIST_ERROR       = "1078"
    WAITING                 = "1079"
    UNKNOWN_LOCKKEY         = "1080"
    BUSY_ERROR              = "1081"
    ALREADY_MOUNT           = "1082"
    ALREADY_UNMOUNT         = "1083"
    QUEUE                   = "1084"
    INVALID_CODE            = "1085"
    ALREADY_REMOVED         = "1086"
    DISK_ERROR              = "1087"
    UNLOCK_ERROR            = "1088"
    WRITE_ERROR             = "1089"
    ALREADY_STOP            = "1090"
    NOT_SUPPORTED           = "1091"
    NO_FEATURE_ERROR        = "1092"
    EXTEND_ERROR            = "1093"
    SWITCH_ERROR            = "1094"
    IMPORT_ERROR            = "1095"
    EXPORT_ERROR            = "1096"
    SCAN_ERROR              = "1097"
